package main

import (
	"bytes"
	"errors"
	"strings"
	"text/template"

	"gopkg.in/yaml.v3"
)

type contentRequirement struct {
	content string
	data    requirement
}

func splitYamlParts(content []byte) (error, contentRequirement) {

	origin := string(content)

	meta := ""
	text := ""

	before, remaining, found := strings.Cut(origin, "---")
	if !found {

		t := strings.TrimSpace(origin)
		if len(t) == 0 {
			return errors.New("the file is empty"), contentRequirement{
				content: origin,
				data:    requirement{},
			}
		}

		return errors.New("the file does not contain a definition block"), contentRequirement{
			content: origin,
			data:    requirement{},
		}
	}

	text += before

	a, b, found := strings.Cut(remaining, "...")
	if !found {
		a, b, found = strings.Cut(remaining, "---")

		if !found {
			return errors.New("the file does not contain a definition block"), contentRequirement{}
		}

	}

	meta = a
	text += b

	t, err := template.New("overview").Parse(text)
	if err != nil {
		return err, contentRequirement{}
	}

	data := requirement{}
	err = yaml.Unmarshal([]byte(meta), &data)
	if err != nil {
		printError("YAML parse error", err.Error())
		return err, contentRequirement{}
	}

	for i, _ := range data.Items {
		data.Items[i].ID = data.ID + "-" + data.Items[i].ID
	}

	req := contentRequirement{}
	req.data = data

	var buffer bytes.Buffer
	err = t.Execute(&buffer, data)
	if err != nil {
		printError(err.Error())
		return err, contentRequirement{}
	}

	req.content = buffer.String()

	return nil, req

}

func translateHeaders(columns []string) []string {

	result := []string{}

	for _, column := range columns {
		result = append(result, printer.Sprintf(column))
	}

	return result

}
